@@ -995,8 +995,8 @@ void dict_gui_about_dialog(GtkWidget *widget, DictData *dd)
 		"destroy-with-parent", TRUE,
 		"authors", authors,
 		"comments", _("A client program to query different dictionaries."),
-		"copyright", _("Copyright \302\251 2006-2016 Xfce Development Team"),
-		"website", "http://goodies.xfce.org/projects/applications/xfce4-dict",
+		"copyright", _("Copyright \302\251 2006-2020 Xfce Development Team"),
+		"website", "https://docs.xfce.org/apps/xfce4-dict/start",
 		"logo", logo,
 		"translator-credits", _("translator-credits"),
 		"license", XFCE_LICENSE_GPL,
