@@ -382,7 +382,7 @@ static void sr_start(XfdSpeedReader *dialog)
 
 	if (G_LIKELY (font))
 	{
-		css = g_strdup_printf("label { font-family: %s; font-size: %dpx; font-style: %s; font-weight: %s }",
+		css = g_strdup_printf("label { font-family: %s; font-size: %dpt; font-style: %s; font-weight: %s }",
 													pango_font_description_get_family (font),
 													pango_font_description_get_size (font) / PANGO_SCALE,
 													(pango_font_description_get_style(font) == PANGO_STYLE_ITALIC ||
